@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "richtextcomposer.h"
@@ -131,7 +118,7 @@ void RichTextComposer::createActions(KActionCollection *ac)
 
 void RichTextComposer::updateHighLighter()
 {
-    KPIMTextEdit::RichTextComposerEmailQuoteHighlighter *hlighter = qobject_cast<KPIMTextEdit::RichTextComposerEmailQuoteHighlighter *>(highlighter());
+    auto *hlighter = qobject_cast<KPIMTextEdit::RichTextComposerEmailQuoteHighlighter *>(highlighter());
     if (hlighter) {
         hlighter->toggleSpellHighlighting(checkSpellingEnabled());
     }
@@ -256,9 +243,9 @@ void RichTextComposer::forcePlainTextMarkup(bool force)
 void RichTextComposer::insertPlainTextImplementation()
 {
     if (d->forcePlainTextMarkup) {
-        KPIMTextEdit::PlainTextMarkupBuilder *pb = new KPIMTextEdit::PlainTextMarkupBuilder();
+        auto *pb = new KPIMTextEdit::PlainTextMarkupBuilder();
         pb->setQuotePrefix(defaultQuoteSign());
-        KPIMTextEdit::MarkupDirector *pmd = new KPIMTextEdit::MarkupDirector(pb);
+        auto *pmd = new KPIMTextEdit::MarkupDirector(pb);
         pmd->processDocument(document());
         const QString plainText = pb->getResult();
         document()->setPlainText(plainText);
@@ -596,7 +583,7 @@ void RichTextComposer::insertFromMimeData(const QMimeData *source)
                 || sourceText.startsWith(QLatin1String("fish://"))
                 || sourceText.startsWith(QLatin1String("tel:"))
                 ) {
-                insertHtml(QStringLiteral("<a href=\"%1\">%1</a> ").arg(sourceText));
+                insertHtml(QStringLiteral("<a href=\"%1\">%1</a>").arg(sourceText));
                 return;
             }
         }
