@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPIMTEXTEDITRICHTEXTCOMPOSERIMAGES_H
@@ -50,8 +37,8 @@ struct ImageWithName {
 };
 
 typedef QSharedPointer<ImageWithName> ImageWithNamePtr;
-typedef QList< ImageWithNamePtr > ImageWithNameList;
-typedef QList< QSharedPointer<EmbeddedImage> > ImageList;
+typedef QVector< ImageWithNamePtr > ImageWithNameList;
+typedef QVector< QSharedPointer<EmbeddedImage> > ImageList;
 
 class KPIMTEXTEDIT_EXPORT RichTextComposerImages : public QObject
 {
@@ -87,8 +74,8 @@ public:
 
     void addImageHelper(const QString &imageName, const QImage &image, int width = -1, int height = -1);
     Q_REQUIRED_RESULT ImageWithNameList imagesWithName() const;
-    Q_REQUIRED_RESULT QList<QSharedPointer<EmbeddedImage> > embeddedImages() const;
-    Q_REQUIRED_RESULT QList<QTextImageFormat> embeddedImageFormats() const;
+    Q_REQUIRED_RESULT QVector<QSharedPointer<EmbeddedImage> > embeddedImages() const;
+    Q_REQUIRED_RESULT QVector<QTextImageFormat> embeddedImageFormats() const;
     void addImageHelper(const QUrl &url, int width = -1, int height = -1);
     void insertImage(const QImage &image, const QFileInfo &fileInfo);
 
@@ -109,7 +96,7 @@ public:
      *
      * @return a modified HTML code, where the \<img\> tags got replaced
      */
-    static QByteArray imageNamesToContentIds(const QByteArray &htmlBody, const ImageList &imageList);
+    static Q_REQUIRED_RESULT QByteArray imageNamesToContentIds(const QByteArray &htmlBody, const ImageList &imageList);
 
     Q_REQUIRED_RESULT QSharedPointer<EmbeddedImage> createEmbeddedImage(const QImage &img, const QString &imageName) const;
 private:
