@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "plaintexteditor.h"
 #include "kpimtextedit_debug.h"
@@ -75,9 +62,9 @@ public:
     }
 
     QStringList ignoreSpellCheckingWords;
-    PlainTextEditor *q;
-    KPIMTextEdit::TextMessageIndicator *mTextIndicator = nullptr;
-    KIO::KUriFilterSearchProviderActions *webshortcutMenuManager = nullptr;
+    PlainTextEditor *const q;
+    KPIMTextEdit::TextMessageIndicator *const mTextIndicator;
+    KIO::KUriFilterSearchProviderActions *const webshortcutMenuManager;
     Sonnet::SpellCheckDecorator *richTextDecorator = nullptr;
     Sonnet::Speller *speller = nullptr;
 
@@ -170,7 +157,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
 
                 if (checkSpellingEnabled() && d->activateLanguageMenu) {
                     QMenu *languagesMenu = new QMenu(i18n("Spell Checking Language"), popup);
-                    QActionGroup *languagesGroup = new QActionGroup(languagesMenu);
+                    auto *languagesGroup = new QActionGroup(languagesMenu);
                     languagesGroup->setExclusive(true);
 
                     QString defaultSpellcheckingLanguage = spellCheckingLanguage();
@@ -341,7 +328,7 @@ void PlainTextEditor::slotCheckSpelling()
         slotDisplayMessageIndicator(i18n("Nothing to spell check."));
         return;
     }
-    Sonnet::BackgroundChecker *backgroundSpellCheck = new Sonnet::BackgroundChecker;
+    auto *backgroundSpellCheck = new Sonnet::BackgroundChecker;
     if (backgroundSpellCheck->speller().availableBackends().isEmpty()) {
         slotDisplayMessageIndicator(i18n("No backend available for spell checking."));
         delete backgroundSpellCheck;
@@ -355,7 +342,7 @@ void PlainTextEditor::slotCheckSpelling()
             backgroundSpellCheck->speller().addToSession(word);
         }
     }
-    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, nullptr);
+    auto *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, nullptr);
     backgroundSpellCheck->setParent(spellDialog);
     spellDialog->setAttribute(Qt::WA_DeleteOnClose, true);
     connect(spellDialog, &Sonnet::Dialog::replace, this, &PlainTextEditor::slotSpellCheckerCorrected);
@@ -435,7 +422,7 @@ void PlainTextEditor::deleteWordForward()
 bool PlainTextEditor::event(QEvent *ev)
 {
     if (ev->type() == QEvent::ShortcutOverride) {
-        QKeyEvent *e = static_cast<QKeyEvent *>(ev);
+        auto *e = static_cast<QKeyEvent *>(ev);
         if (overrideShortcut(e)) {
             e->accept();
             return true;
@@ -626,13 +613,25 @@ void PlainTextEditor::deleteEndOfLine()
     setTextCursor(cursor);
 }
 
+void PlainTextEditor::moveCursorBeginUpDown(bool moveUp)
+{
+    QTextCursor cursor = textCursor();
+    QTextCursor move = cursor;
+    move.beginEditBlock();
+    cursor.clearSelection();
+    move.movePosition(QTextCursor::StartOfBlock);
+    move.movePosition(moveUp ? QTextCursor::PreviousBlock : QTextCursor::NextBlock);
+    move.endEditBlock();
+    setTextCursor(move);
+}
+
 void PlainTextEditor::moveLineUpDown(bool moveUp)
 {
     QTextCursor cursor = textCursor();
     QTextCursor move = cursor;
     move.beginEditBlock();
 
-    bool hasSelection = cursor.hasSelection();
+    const bool hasSelection = cursor.hasSelection();
 
     if (hasSelection) {
         move.setPosition(cursor.selectionStart());
@@ -644,7 +643,7 @@ void PlainTextEditor::moveLineUpDown(bool moveUp)
         move.movePosition(QTextCursor::StartOfBlock);
         move.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
     }
-    QString text = move.selectedText();
+    const QString text = move.selectedText();
 
     move.movePosition(QTextCursor::Right, QTextCursor::KeepAnchor);
     move.removeSelectedText();
@@ -706,6 +705,12 @@ void PlainTextEditor::keyPressEvent(QKeyEvent *event)
     } else if (event->key() == Qt::Key_Down && isControlClicked && isShiftClicked) {
         moveLineUpDown(false);
         event->accept();
+    } else if (event->key() == Qt::Key_Up && isControlClicked) {
+        moveCursorBeginUpDown(true);
+        event->accept();
+    } else if (event->key() == Qt::Key_Down && isControlClicked) {
+        moveCursorBeginUpDown(false);
+        event->accept();
     } else {
         QPlainTextEdit::keyPressEvent(event);
     }
@@ -841,7 +846,7 @@ QString PlainTextEditor::spellCheckingConfigFileName() const
 
 void PlainTextEditor::slotLanguageSelected()
 {
-    QAction *languageAction = static_cast<QAction *>(QObject::sender());
+    auto *languageAction = static_cast<QAction *>(QObject::sender());
     setSpellCheckingLanguage(languageAction->data().toString());
 }
 
